@@ -7,18 +7,17 @@
 #ifndef DEVICE_H
 #define DEVICE_H
 
+#include <QHostAddress>
 #include <QObject>
 #include <QString>
-#include <QHostAddress>
 
-#include "networkpacket.h"
 #include "backends/devicelink.h"
+#include "networkpacket.h"
 
 class DeviceLink;
 class KdeConnectPlugin;
 
-class KDECONNECTCORE_EXPORT Device
-    : public QObject
+class KDECONNECTCORE_EXPORT Device : public QObject
 {
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.kde.kdeconnect.device")
@@ -32,7 +31,6 @@ class KDECONNECTCORE_EXPORT Device
     Q_PROPERTY(bool hasPairingRequests READ hasPairingRequests NOTIFY hasPairingRequestsChanged)
 
 public:
-
     enum DeviceType {
         Unknown,
         Desktop,
@@ -47,29 +45,32 @@ public:
      *
      * We already know it but we need to wait for an incoming DeviceLink to communicate
      */
-    Device(QObject* parent, const QString& id);
+    Device(QObject *parent, const QString &id);
 
     /**
      * Device known via an incoming connection sent to us via a devicelink.
      *
      * We know everything but we don't trust it yet
      */
-    Device(QObject* parent, const NetworkPacket& np, DeviceLink* dl);
+    Device(QObject *parent, const NetworkPacket &np, DeviceLink *dl);
 
     ~Device() override;
 
     QString id() const;
     QString name() const;
-    QString dbusPath() const { return QStringLiteral("/modules/kdeconnect/devices/") + id(); }
+    QString dbusPath() const
+    {
+        return QStringLiteral("/modules/kdeconnect/devices/") + id();
+    }
     QString type() const;
     QString iconName() const;
     QString statusIconName() const;
     Q_SCRIPTABLE QByteArray verificationKey() const;
     Q_SCRIPTABLE QString encryptionInfo() const;
 
-    //Add and remove links
-    void addLink(const NetworkPacket& identityPacket, DeviceLink*);
-    void removeLink(DeviceLink*);
+    // Add and remove links
+    void addLink(const NetworkPacket &identityPacket, DeviceLink *);
+    void removeLink(DeviceLink *);
 
     Q_SCRIPTABLE bool isTrusted() const;
 
@@ -77,13 +78,13 @@ public:
     virtual bool isReachable() const;
 
     Q_SCRIPTABLE QStringList loadedPlugins() const;
-    Q_SCRIPTABLE bool hasPlugin(const QString& name) const;
+    Q_SCRIPTABLE bool hasPlugin(const QString &name) const;
 
     Q_SCRIPTABLE QString pluginsConfigFile() const;
 
-    KdeConnectPlugin* plugin(const QString& pluginName) const;
-    Q_SCRIPTABLE void setPluginEnabled(const QString& pluginName, bool enabled);
-    Q_SCRIPTABLE bool isPluginEnabled(const QString& pluginName) const;
+    KdeConnectPlugin *plugin(const QString &pluginName) const;
+    Q_SCRIPTABLE void setPluginEnabled(const QString &pluginName, bool enabled);
+    Q_SCRIPTABLE bool isPluginEnabled(const QString &pluginName) const;
 
     void cleanUnneededLinks();
 
@@ -93,45 +94,45 @@ public:
     QHostAddress getLocalIpAddress() const;
 
 public Q_SLOTS:
-    ///sends a @p np packet to the device
-    ///virtual for testing purposes.
-    virtual bool sendPacket(NetworkPacket& np);
+    /// sends a @p np packet to the device
+    /// virtual for testing purposes.
+    virtual bool sendPacket(NetworkPacket &np);
 
-    //Dbus operations
+    // Dbus operations
 public Q_SLOTS:
-    Q_SCRIPTABLE void requestPair(); //to all links
-    Q_SCRIPTABLE void unpair(); //from all links
-    Q_SCRIPTABLE void reloadPlugins(); //from kconf
+    Q_SCRIPTABLE void requestPair(); // to all links
+    Q_SCRIPTABLE void unpair(); // from all links
+    Q_SCRIPTABLE void reloadPlugins(); // from kconf
 
     Q_SCRIPTABLE void acceptPairing();
     Q_SCRIPTABLE void rejectPairing();
     Q_SCRIPTABLE bool hasPairingRequests() const;
 
-    Q_SCRIPTABLE QString pluginIconName(const QString& pluginName);
+    Q_SCRIPTABLE QString pluginIconName(const QString &pluginName);
 private Q_SLOTS:
-    void privateReceivedPacket(const NetworkPacket& np);
-    void linkDestroyed(QObject* o);
+    void privateReceivedPacket(const NetworkPacket &np);
+    void linkDestroyed(QObject *o);
     void pairStatusChanged(DeviceLink::PairStatus current);
-    void addPairingRequest(PairingHandler* handler);
-    void removePairingRequest(PairingHandler* handler);
+    void addPairingRequest(PairingHandler *handler);
+    void removePairingRequest(PairingHandler *handler);
 
 Q_SIGNALS:
     Q_SCRIPTABLE void pluginsChanged();
     Q_SCRIPTABLE void reachableChanged(bool reachable);
     Q_SCRIPTABLE void trustedChanged(bool trusted);
-    Q_SCRIPTABLE void pairingError(const QString& error);
-    Q_SCRIPTABLE void nameChanged(const QString& name);
-    Q_SCRIPTABLE void typeChanged(const QString& type);
+    Q_SCRIPTABLE void pairingError(const QString &error);
+    Q_SCRIPTABLE void nameChanged(const QString &name);
+    Q_SCRIPTABLE void typeChanged(const QString &type);
     Q_SCRIPTABLE void statusIconNameChanged();
 
     Q_SCRIPTABLE void hasPairingRequestsChanged(bool hasPairingRequests);
 
-private: //Methods
-    static DeviceType str2type(const QString& deviceType);
+private: // Methods
+    static DeviceType str2type(const QString &deviceType);
     static QString type2str(DeviceType deviceType);
 
-    void setName(const QString& name);
-    void setType(const QString& strtype);
+    void setName(const QString &name);
+    void setType(const QString &strtype);
     QString iconForStatus(bool reachable, bool paired) const;
     QSslCertificate certificate() const;
 
@@ -140,6 +141,6 @@ private:
     DevicePrivate *d;
 };
 
-Q_DECLARE_METATYPE(Device*)
+Q_DECLARE_METATYPE(Device *)
 
 #endif // DEVICE_H
